@@ -3,6 +3,7 @@
 # SPDX-FileCopyrightText: Peter Pentchev <roam@ringlet.net>
 # SPDX-License-Identifier: BSD-2-Clause
 
+: "${PYTHON3:=python3}"
 
 env PYTHONPATH="$(dirname -- "$(dirname -- "$0")")/src${PYTHONPATH+:${PYTHONPATH}}" \
-    python3 -m feature_check "$@"
+    "$PYTHON3" -m feature_check "$@"
