@@ -76,7 +76,8 @@ def _def_op_bool_ver(check: Callable[[int], bool]) -> BoolOpFunction:
         """Check whether the arguments are in the expected relation."""
         match args:
             case [left, right] if isinstance(left, ResultVersion) and isinstance(
-                right, ResultVersion
+                right,
+                ResultVersion,
             ):
                 return check(fver.version_compare(left.value, right.value))
 
