@@ -32,7 +32,7 @@ class ObtainNoFeaturesSupportError(ObtainExecError):
         """Store the program name."""
         super().__init__(
             f"The {program} program does not seem to support "
-            f"the {option} option for querying features"
+            f"the {option} option for querying features",
         )
 
 
@@ -77,8 +77,8 @@ def obtain_features(
 
     def try_run() -> list[str]:
         """Query a program about its features, return the output lines."""
-        res: Final = subprocess.run(
-            [program, option],  # noqa: S603
+        res: Final = subprocess.run(  # noqa: S603
+            [program, option],
             capture_output=True,
             check=False,
             stdin=None,
@@ -94,13 +94,19 @@ def obtain_features(
     except ObtainExecError:
         raise
     # Yes, we do want to convert any error into an ObtainExecError one
-    except Exception as exc:  # noqa: BLE001
+    except Exception as exc:
         # Something went wrong in the --features processing
         raise ObtainExecError(str(exc)) from exc
 
-    matching: Final = [
-        rest for line, rest in ((line, line.removeprefix(prefix)) for line in lines) if rest != line
-    ]
+    matching: Final = (
+        [
+            rest
+            for line, rest in ((line, line.removeprefix(prefix)) for line in lines)
+            if rest != line
+        ]
+        if prefix
+        else [line for line in lines if line]
+    )
     if len(matching) != 1:
         raise ObtainNoFeaturesError(program, option, prefix)
 
