@@ -10,6 +10,7 @@ use std::str::FromStr;
 
 use anyhow::{anyhow, bail, Context, Error, Result};
 use clap::{CommandFactory, Parser};
+use clap_derive::Parser;
 
 use feature_check::defs::{Config, Mode, Obtained, DEFAULT_OPTION_NAME, DEFAULT_PREFIX};
 use feature_check::expr::{self as fexpr, CalcResult};
@@ -46,7 +47,7 @@ impl FromStr for OutputFormat {
         match value {
             Self::JSON_NAME => Ok(Self::Json),
             Self::TSV_NAME => Ok(Self::Tsv),
-            other => Err(anyhow!(format!("Unrecognized output format '{other}'"))),
+            other => Err(anyhow!("Unrecognized output format '{other}'")),
         }
     }
 }
@@ -116,15 +117,15 @@ struct Cli {
     list: bool,
 
     /// Specify the query-features option to pass to the program.
-    #[clap(short = 'O', default_value = DEFAULT_OPTION_NAME)]
+    #[clap(short = 'O', default_value = DEFAULT_OPTION_NAME, allow_hyphen_values = true)]
     optname: String,
 
     /// Specify the output format for the list of features.
-    #[clap(short = 'o', default_value = OutputFormat::TSV_NAME)]
+    #[clap(short = 'o', default_value = OutputFormat::TSV_NAME, allow_hyphen_values = true)]
     output_format: OutputFormat,
 
     /// The features prefix in the program output.
-    #[clap(short = 'P', default_value = DEFAULT_PREFIX)]
+    #[clap(short = 'P', default_value = DEFAULT_PREFIX, allow_hyphen_values = true)]
     prefix: String,
 
     /// Output the feature version when querying a single feature".
@@ -233,7 +234,7 @@ fn run(config: MainConfig) -> Result<MainResult> {
                             MainResult::Ok
                         }
                         CalcResult::Null => MainResult::FeatureNotSupported,
-                        other => bail!(format!("single.get_value() returned {other:?}")),
+                        other => bail!("single.get_value() returned {other:?}"),
                     }
                 }
                 Mode::List => match config.output_format {
@@ -262,16 +263,12 @@ fn run(config: MainConfig) -> Result<MainResult> {
                     match value {
                         CalcResult::Bool(true) => MainResult::Ok,
                         CalcResult::Bool(false) => MainResult::FeatureNotSupported,
-                        other => bail!(format!("parse_simple().get_value() returned {other:?}")),
+                        other => bail!("parse_simple().get_value() returned {other:?}"),
                     }
                 }
-                other => bail!(format!(
-                    "Internal error: unexpected mode {other:?} after obtain_features()"
-                )),
+                other => bail!("Internal error: unexpected mode {other:?} after obtain_features()"),
             },
-            other => bail!(format!(
-                "Internal error: obtain_features() returned something weird: {other:?}"
-            )),
+            other => bail!("Internal error: obtain_features() returned something weird: {other:?}"),
         },
     )
 }
