@@ -54,7 +54,7 @@ use std::str::FromStr;
 use std::vec::IntoIter as VecIntoIter;
 
 use anyhow::Error as AnyError;
-use serde::Serialize;
+use serde_derive::{Deserialize, Serialize};
 use thiserror::Error;
 
 use crate::expr::parser;
@@ -141,7 +141,7 @@ fn compare_components(left: &[VersionComponent], right: &[VersionComponent]) ->
 }
 
 /// A version string, both in full and broken down into components.
-#[derive(Debug, Clone, Serialize)]
+#[derive(Debug, Clone, Deserialize, Serialize)]
 #[serde(transparent)]
 pub struct Version {
     /// The full version string.
